searchNodes=[{"type":"module","title":"sleeplocks","doc":"BEAM friendly spinlocks for Elixir/Erlang. This module provides a very simple API for managing locks inside a BEAM instance. It's modeled on spinlocks, but works through message passing rather than loops. Locks can have multiple slots to enable arbitrary numbers of associated processes. The moment a slot is freed, the next awaiting process acquires the lock. All of this is done in a simple Erlang process so there's very little dependency, and management is extremely simple.","ref":"sleeplocks.html"},{"type":"function","title":"sleeplocks.acquire/1","doc":"Acquires a lock for the current process. This will block until a lock can be acquired.","ref":"sleeplocks.html#acquire/1"},{"type":"function","title":"sleeplocks.attempt/1","doc":"Attempts to acquire a lock for the current process. In the case there are no slots available, an error will be returned immediately rather than waiting.","ref":"sleeplocks.html#attempt/1"},{"type":"function","title":"sleeplocks.code_change/3","doc":"","ref":"sleeplocks.html#code_change/3"},{"type":"function","title":"sleeplocks.execute/2","doc":"Executes a function when a lock can be acquired. The lock is automatically released after the function has completed execution; there's no need to manually release.","ref":"sleeplocks.html#execute/2"},{"type":"function","title":"sleeplocks.handle_call/3","doc":"","ref":"sleeplocks.html#handle_call/3"},{"type":"function","title":"sleeplocks.handle_cast/2","doc":"","ref":"sleeplocks.html#handle_cast/2"},{"type":"function","title":"sleeplocks.handle_info/2","doc":"","ref":"sleeplocks.html#handle_info/2"},{"type":"function","title":"sleeplocks.init/1","doc":"","ref":"sleeplocks.html#init/1"},{"type":"function","title":"sleeplocks.new/1","doc":"Creates a new lock with a provided concurrency factor.","ref":"sleeplocks.html#new/1"},{"type":"function","title":"sleeplocks.new/2","doc":"Creates a new lock with a provided concurrency factor.","ref":"sleeplocks.html#new/2"},{"type":"function","title":"sleeplocks.release/1","doc":"Releases a lock held by the current process.","ref":"sleeplocks.html#release/1"},{"type":"function","title":"sleeplocks.start_link/1","doc":"","ref":"sleeplocks.html#start_link/1"},{"type":"function","title":"sleeplocks.start_link/2","doc":"","ref":"sleeplocks.html#start_link/2"},{"type":"function","title":"sleeplocks.terminate/2","doc":"","ref":"sleeplocks.html#terminate/2"},{"type":"type","title":"sleeplocks.name/0","doc":"","ref":"sleeplocks.html#t:name/0"},{"type":"type","title":"sleeplocks.start_ret/0","doc":"","ref":"sleeplocks.html#t:start_ret/0"},{"type":"extras","title":"sleeplocks","doc":"This library is designed to provide simple locking mechanisms in Erlang/Elixir, similar to how spinlocks work in other languages - except using messages to communicate locking. This is useful for libraries which require lock synchronization, without having to roll your own (however simple). Locks can be held by arbitrary numbers of process, making it possible to implement various throttling mechanisms. Best of all, this library is tiny! It builds upon basic OTP principles to implement lock behaviour via simple processes and message passing.","ref":"readme.html"},{"type":"extras","title":"sleeplocks - Installation","doc":"Rebar Follow the instructons found here to configure your Rebar setup to use Hex as a dependency source, then you can grab it directly: { deps , [ % pulls the latest version sleeplocks , % to pull the latest version from github { sleeplocks , { git , &quot;git://github.com/whitfin/sleeplocks.git&quot; } } ] } . Mix To install it for your project, you can pull it directly from Hex. Rather than use the version shown below, you can use the latest version from Hex (shown at the top of this README). def deps do [ { :sleeplocks , &quot;~&gt; 1.0&quot; } ] end","ref":"readme.html#installation"},{"type":"extras","title":"sleeplocks - Usage","doc":"Snippets below contain sample usage in both Erlang and Elixir, and cover most of the small API space offered by sleeplocks . For a more complete example, scroll down! Erlang % create a new single lock (with a name) 1 &gt; sleeplocks : new ( 1 , [ { name , { local , my_lock } } ] ) . { ok , &lt; 0.179 . 0 &gt; } % take ownership of the lock 2 &gt; sleeplocks : acquire ( my_lock ) . ok % release the current hold on a lock 3 &gt; sleeplocks : release ( my_lock ) . ok % attempt to acquire a lock (which will succeed) 4 &gt; sleeplocks : attempt ( my_lock ) . ok % now that it&#39;s taken, other attempts will fail 5 &gt; sleeplocks : attempt ( my_lock ) . { error , unavailable } % release the lock again 6 &gt; sleeplocks : release ( my_lock ) . ok % handle acquisition and locking automatically 7 &gt; sleeplocks : execute ( my_lock , fun ( ) -&gt; 7 &gt; 3 7 &gt; end ) . 3 Elixir # create a new single lock (with a name) iex(1)&gt; :sleeplocks . new ( 1 , [ name : :my_lock ] ) { :ok , # PID &lt; 0 . 179 . 0 &gt; } # take ownership of the lock iex(2)&gt; :sleeplocks . acquire ( :my_lock ) :ok # release the current hold on a lock iex(3)&gt; :sleeplocks . release ( :my_lock ) :ok # attempt to acquire a lock (which will succeed) iex(4)&gt; :sleeplocks . attempt ( :my_lock ) :ok # now that it&#39;s taken, other attempts will fail iex(5)&gt; :sleeplocks . attempt ( :my_lock ) { :error , :unavailable } # release the lock again iex(6)&gt; :sleeplocks . release ( :my_lock ) :ok # handle acquisition and locking automatically iex(7)&gt; :sleeplocks . execute ( :my_lock , fn -&gt; iex(7)&gt; 3 iex(7)&gt; end ) 3","ref":"readme.html#usage"},{"type":"extras","title":"sleeplocks - Examples","doc":"This example is in Elixir, but it should be fairly understandable for those coming from both languages. It simply spawns 6 processes which each attempt to hold a lock for 10 seconds. As the lock is created with only 2 slots, this runs for 30 seconds and 2 of our spawned tasks can hold the lock at any given time. # First create a new lock, with 2 slots only { :ok , ref } = :sleeplocks . new ( 2 ) # Then spawn 6 tasks, which each just sleep for 10 seconds # after acquiring the lock. This means that 2 processes will # acquire a lock and then release after 10 seconds. This # will repeat 3 times (6 / 2) until 30 seconds are up. for idx &lt;- 1 .. 6 do Task . start ( fn -&gt; :sleeplocks . execute ( ref , fn -&gt; IO . puts ( &quot;Locked \#{ idx } &quot; ) Process . sleep ( 10_000 ) IO . puts ( &quot;Releasing \#{ idx } &quot; ) end ) end ) end","ref":"readme.html#examples"},{"type":"extras","title":"LICENSE","doc":"MIT License Copyright (c) 2019 Isaac Whitfield Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}]